==> comedi-0.6.6.tgz: comedi-0.6.6/include/comedilib.h <==
/*
    include/comedilib.h
    header file for the comedi library routines

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1998 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/


#ifndef _COMEDILIB_H
#define _COMEDILIB_H

#include <comedi.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif

#define UNIT_V		0
#define UNIT_mA		1
#define UNIT_none	2

typedef struct comedi_t_struct{
	int magic;

	int fd;
	int n_subdevices;

	comedi_devinfo devinfo;

	comedi_subdinfo *subdevices;
}comedi_t;

typedef struct{
	double min;
	double max;
	unsigned int unit;
}comedi_range;

typedef struct comedi_sv_struct{
	comedi_t *dev;
	unsigned int subdevice;
	unsigned int chan;

	/* range policy */
	int range;
	int aref;
	
	/* number of measurements to average (for ai) */
	int n;

	int rangetype;
	sampl_t maxdata;
}comedi_sv_t;

#if 0
typedef struct{
	unsigned int maxdata;
	double offset;
	double max;
	double delta;
}comedi_voltage_info;
#endif

/*
   comedi_version_code is the version of the comedi source that
   the library came from.  It is used to verify compatibility with
   a running kernel module.
 */
extern unsigned int comedi_version_code;

extern comedi_range comedi_ranges[];

int comedi_put(int fd,unsigned int subdev,unsigned int chan,unsigned int range,
		unsigned int aref,sampl_t data);
int comedi_get(int fd,unsigned int subdev,unsigned int chan,unsigned int range,
		unsigned int aref);


/* ioctl wrappers */

int comedi_get_devinfo(int fd,comedi_devinfo *it);
int comedi_get_subdinfo(int fd,comedi_subdinfo *it);
int comedi_get_chaninfo(int fd,unsigned int subdev,sampl_t *maxdata_list,
		unsigned int *flaglist,unsigned int *rangelist);
int comedi_trigger(int fd,comedi_trig *it);
int comedi_lock(int fd,int subdevice);
int comedi_unlock(int fd,int subdevice);
int comedi_cancel(int fd,int subdevice);

/* stuff */

comedi_t *comedi_open(char *fn);
void comedi_close(comedi_t *it);

int comedi_get_maxdata(comedi_t *it,unsigned int subdevice,int chan);
int comedi_get_rangetype(comedi_t *it,unsigned int subdevice,int chan);

int comedi_update_subd_info(comedi_t *it);
int comedi_update_chan_info(comedi_t *it,unsigned int subdevice);


/* range stuff */

comedi_range *comedi_get_ranges(unsigned int range_type);
unsigned int comedi_get_n_ranges(unsigned int range_type);

double comedi_to_phys(sampl_t data,comedi_range *rng,sampl_t maxdata);
sampl_t comedi_from_phys(double data,comedi_range *rng,sampl_t maxdata);

/* slowly varying stuff */

int comedi_sv_init(comedi_sv_t *it,comedi_t *dev,unsigned int subd,unsigned int chan);
int comedi_sv_update(comedi_sv_t *it);
int comedi_sv_measure(comedi_sv_t *it,double *data);



#ifdef __cplusplus
}
#endif

#endif

==> comedi-0.6.10.tgz: comedi-0.6.10/include/comedilib.h <==
/*
    include/comedilib.h
    header file for the comedi library routines

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1998 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/


#ifndef _COMEDILIB_H
#define _COMEDILIB_H

#include <comedi.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif

#define UNIT_V		0
#define UNIT_mA		1
#define UNIT_none	2

typedef struct comedi_t_struct{
	int magic;

	int fd;
	int n_subdevices;

	comedi_devinfo devinfo;

	comedi_subdinfo *subdevices;
}comedi_t;

typedef struct{
	double min;
	double max;
	unsigned int unit;
}comedi_range;

typedef struct comedi_sv_struct{
	comedi_t *dev;
	unsigned int subdevice;
	unsigned int chan;

	/* range policy */
	int range;
	int aref;
	
	/* number of measurements to average (for ai) */
	int n;

	int rangetype;
	sampl_t maxdata;
}comedi_sv_t;

/*
   comedi_version_code is the version of the comedi source that
   the library came from.  It is used to verify compatibility with
   a running kernel module.
 */
extern unsigned int comedi_version_code;

extern comedi_range comedi_ranges[];

int comedi_put(int fd,unsigned int subdev,unsigned int chan,unsigned int range,
		unsigned int aref,sampl_t data);
int comedi_get(int fd,unsigned int subdev,unsigned int chan,unsigned int range,
		unsigned int aref);


/* ioctl wrappers */

int comedi_get_devinfo(int fd,comedi_devinfo *it);
int comedi_get_subdinfo(int fd,comedi_subdinfo *it);
int comedi_get_chaninfo(int fd,unsigned int subdev,sampl_t *maxdata_list,
		unsigned int *flaglist,unsigned int *rangelist);
int comedi_trigger(int fd,comedi_trig *it);
int comedi_lock(int fd,int subdevice);
int comedi_unlock(int fd,int subdevice);
int comedi_cancel(int fd,int subdevice);

/* stuff */

comedi_t *comedi_open(char *fn);
void comedi_close(comedi_t *it);

int comedi_get_maxdata(comedi_t *it,unsigned int subdevice,int chan);
int comedi_get_rangetype(comedi_t *it,unsigned int subdevice,int chan);

int comedi_update_subd_info(comedi_t *it);
int comedi_update_chan_info(comedi_t *it,unsigned int subdevice);


/* range stuff */

comedi_range *comedi_get_range(unsigned int range_type,unsigned int range);

#define comedi_get_ranges(a)	comedi_get_range((a),0)

unsigned int comedi_get_n_ranges(unsigned int range_type);

double comedi_to_phys(sampl_t data,comedi_range *rng,sampl_t maxdata);
sampl_t comedi_from_phys(double data,comedi_range *rng,sampl_t maxdata);

/* slowly varying stuff */

int comedi_sv_init(comedi_sv_t *it,comedi_t *dev,unsigned int subd,unsigned int chan);
int comedi_sv_update(comedi_sv_t *it);
int comedi_sv_measure(comedi_sv_t *it,double *data);

/* timer stuff */

int comedi_get_timer(comedi_t *it,unsigned int subdev,double freq,unsigned int *trigvar,
	double *actual_freq);


#ifdef __cplusplus
}
#endif

#endif
